
RELEASE_VERSION='0.2.526009211'
BUILD_DATE='Wed Apr 27 14:48:56 UTC 2022'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-079cpp 5.4.181-99.354.amzn2.x86_64 #1 SMP Wed Mar 2 18:50:46 UTC 2022 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='2384359294'
GIT_COMMIT_SHA='0f41d560424b3c6bb6342866863f7ff6b965a636'
GIT_BRANCH='main'
